#!/bin/sh
#
#  File:  createdoc.sh
#
#  Purpose: For all source modules in the production, creates documentation
#    from the source files.
#
#  Assumptions: Script is started from within the etc directory.

# See if doxygen is installed and report error if it is not

Doxygen=$(which doxygen)

if [ x"$Doxygen" = x ]
then
    echo doxygen not found. Please make doxygen tool available to this script!
    exit 1;
fi

# Go to the base production directory
cd ..

# If it does not exist, create root documentation directory
if [[ ! -e docs ]];
then
    mkdir docs;
fi

# If it does not exist, create doxygen configuration files directory
if [[ ! -e docs/doxyfiles ]];
then
    mkdir docs/doxyfiles;
fi

# If it does not exist, create root modules documentation directory
if [[ ! -e docs/modules ]];
then
    mkdir docs/modules;
fi


# Read all the modules from local/modules.txt

ModFile=./local/modules.txt

while read One Two ModName ModTag; do
# For each module, create module doxygen configuration file

    if [ "$ModTag" != "Latest" ];
    then
        Suffix=-$ModTag
    fi

    echo PROJECT_NAME     = $ModName$Suffix   >> docs/doxyfiles/Doxyfile-$ModName$Suffix
    echo PROJECT_NUMBER   = $ModTag   >> docs/doxyfiles/Doxyfile-$ModName$Suffix
    echo OUTPUT_DIRECTORY = docs/modules/$ModName$Suffix >> docs/doxyfiles/Doxyfile-$ModName$Suffix
    echo INPUT = ./$ModName$Suffix >> docs/doxyfiles/Doxyfile-$ModName$Suffix
 
    cat etc/Doxyfile-template >> docs/doxyfiles/Doxyfile-$ModName$Suffix

# For each module run doxygen to generate documentation
    doxygen docs/doxyfiles/Doxyfile-$ModName$Suffix

done < $ModFile

echo Done.

